==> saas_co-4.5.tar.gz: saas_co-4.5/saas_co/iterate.py <==
from .session import assume_role

def get_account_regions(accounts):
    account_regions = list(set([(a['account_id'], a['region']) for a in accounts]))
    return [{'account_id':a[0], 'region':a[1]} for a in account_regions]

def get_session(args):
    reg = args.get('region')
    aid = args.get('account_id')
    ss = args.get('session')
    accounts = args.get('accounts')
    if not ss:
        ss = {}
        account_regions = get_account_regions(accounts)
        for a in account_regions: ss.update({aid:{}})
    s = ss.get(aid,{}).get(reg,None)
    if not s:
        try:     ss[aid][reg] = assume_role(access_key_id = arg.get('access_key'), 
                                            secret_access_key = arg.get('secret'), 
                                            accountId = aid, 
                                            roleName = arg.get('role'), 
                                            region=reg)
        except:  pass
    return {'accounts':accounts, 'session':ss}

def update_dataframe_with_func(**kargs):
    accounts = kargs.get('cur',[])
    session = kargs.get('session')
    data = {'accounts':accounts, 'session':session}
    results = [run_func(a, data, **kargs) for a in accounts]
    return (results, data['session'])

def run_func(a, data, **kargs):
    print(a)
    account_id = a.get('account_id')
    region = a.get('region')
    data.update({'account_id':account_id, 'region':region})
    data = get_session(data)
    s = data.get('session',{}).get(account_id,{}).get(region,None)
    if s:
        kargs.update({'session':s,'row':a})
        a.update({kargs.get('key'): kargs.get('func')(s, **kargs)})
        return a
    return None

==> saas_co-4.6.tar.gz: saas_co-4.6/saas_co/iterate.py <==
from .session import assume_role

def get_account_regions(accounts):
    account_regions = list(set([(a['account_id'], a['region']) for a in accounts]))
    return [{'account_id':a[0], 'region':a[1]} for a in account_regions]

def get_session(args):
    reg = args.get('region')
    aid = args.get('account_id')
    ss = args.get('session')
    accounts = args.get('accounts')
    if not ss:
        ss = {}
        account_regions = get_account_regions(accounts)
        for a in account_regions: ss.update({aid:{}})
    s = ss.get(aid,{}).get(reg,None)
    if not s:
        try:     ss[aid][reg] = assume_role(access_key_id = args.get('access_key'), 
                                            secret_access_key = args.get('secret'), 
                                            accountId = aid, 
                                            roleName = args.get('role'), 
                                            region=reg)
        except:  pass
    return {'accounts':accounts, 'session':ss}

def update_dataframe_with_func(**kargs):
    accounts = kargs.get('cur',[])
    session = kargs.get('session')
    data = {'accounts':accounts, 'session':session}
    results = [run_func(a, data, **kargs) for a in accounts]
    return (results, data['session'])

def run_func(a, data, **kargs):
    account_id = a.get('account_id')
    region = a.get('region')
    data.update({'account_id':account_id, 'region':region})
    data = get_session(data)
    s = data.get('session',{}).get(account_id,{}).get(region,None)
    if s:
        kargs.update({'session':s,'row':a})
        a.update({kargs.get('key'): kargs.get('func')(s, **kargs)})
        return a
    return None
